import java.awt.*;
import java.util.Random;

public class DrawingSeaplane {
    private EntitySeaplane entitySeaplane;
    private Integer pictureWidth;
    private Integer pictureHeight;
    private Integer _startPosX;
    private Integer _startPosY;
    private final int drawingSeaplaneWidth = 190;
    private final int drawingSeaplaneHeight = 90;
    private DrawingSeaplanePortholes _drawingSeaplanePortholes;
    public EntitySeaplane EntitySeaplane() {
        return entitySeaplane;
    }
    public void Init(int speed, double weight, Color bodyColor, Color additionalColor, boolean floats, boolean inflatableBoat) {
        entitySeaplane = new EntitySeaplane();
        entitySeaplane.Init(speed, weight, bodyColor, additionalColor, floats, inflatableBoat);
        pictureHeight = null;
        pictureWidth = null;
        _startPosX = null;
        _startPosY = null;
        _drawingSeaplanePortholes = new DrawingSeaplanePortholes();
        Random random = new Random();
        int paddlesCount = random.nextInt(1,4);
        _drawingSeaplanePortholes.setPortholesCount(paddlesCount * 10);
    }

    public void setPictureSize(int width, int height) {
        pictureWidth = width;
        pictureHeight = height;
    }

    public void setPosition(int x, int y) {
        if (pictureHeight == null || pictureWidth == null) {
            return;
        }

        if (x < 0) {
            x = 0;
        } else if (x - drawingSeaplaneWidth >= pictureWidth) {
            x = pictureWidth - drawingSeaplaneWidth - drawingSeaplaneWidth;
        }

        if (y < 0) {
            y = 0;
        } else if (y - drawingSeaplaneHeight >= pictureHeight) {
            y = pictureHeight - drawingSeaplaneHeight - drawingSeaplaneHeight;
        }

        _startPosY = y;
        _startPosX = x;
    }

    public boolean moveTransport(DirectionType direction) {
        if (entitySeaplane == null || _startPosX == null || _startPosY == null || pictureWidth == null || pictureHeight == null) {
            return false;
        }

        return switch (direction) {
            case Left -> {
                if (_startPosX - entitySeaplane.getStep() >= 0) {
                    _startPosX -= (int) entitySeaplane.getStep();
                }
                yield true;
            }
            case Up -> {
                if (_startPosY - entitySeaplane.getStep() >= 0) {
                    _startPosY -= (int) entitySeaplane.getStep();
                }
                yield true;
            }
            case Right -> {
                if (_startPosX + entitySeaplane.getStep() <= pictureWidth - drawingSeaplaneWidth) {
                    _startPosX += (int) entitySeaplane.getStep();
                }
                yield true;
            }
            case Down -> {
                if (_startPosY + entitySeaplane.getStep() <= pictureHeight - drawingSeaplaneHeight) {
                    _startPosY += (int) entitySeaplane.getStep();
                }
                yield true;
            }
            default -> false;
        };
    }

    public void drawTransport(Graphics g) {
        if (entitySeaplane == null || _startPosX == null || _startPosY == null) {
            return;
        }

        Graphics2D g2d = (Graphics2D) g;
        g2d.setColor(Color.BLACK);
        // Отрисовка корпуса
        g2d.drawOval(_startPosX, _startPosY + 34, 20, 20);
        g2d.drawOval(_startPosX, _startPosY + 44, 20, 20);
        g2d.drawRect(_startPosX, _startPosY + 45, 10, 10);
        g2d.drawRect(_startPosX + 170, _startPosY + 45, 10, 10);
        g2d.drawRect(_startPosX + 10, _startPosY + 34, 160, 30);

        // Отрисовка верхней части
        int[] xPointsTop = {_startPosX + 170, _startPosX + 170, _startPosX + 190};
        int[] yPointsTop = {_startPosY+30, _startPosY + 50, _startPosY + 50};
        g2d.drawPolygon(xPointsTop, yPointsTop, 3);

        // Отрисовка нижней части
        int[] xPointsBottom = {_startPosX + 170, _startPosX + 170, _startPosX + 190};
        int[] yPointsBottom = {_startPosY + 70, _startPosY + 50, _startPosY + 50};
        g2d.drawPolygon(xPointsBottom, yPointsBottom, 3);

        // Отрисовка киля
        int[] xPointsKeel = {_startPosX + 10, _startPosX + 10, _startPosX + 50};
        int[] yPointsKeel = {_startPosY, _startPosY + 35, _startPosY + 35};
        g2d.drawPolygon(xPointsKeel, yPointsKeel, 3);

        if (!entitySeaplane.getFloats())
        {
            // Рисуем переднее шасси с одним колесом
            g2d.drawOval( _startPosX + 140, _startPosY + 75, 10, 10);

            // Рисуем задние шасси с двумя колесами
            g2d.drawOval( _startPosX + 20, _startPosY + 75, 10, 10);
            g2d.drawOval( _startPosX + 30, _startPosY + 75, 10, 10);

            // Рисуем ногу переднего шасси
            g2d.drawLine( _startPosX + 145, _startPosY + 75, _startPosX + 145, _startPosY + 50);

            // Рисуем ноги заднего шасси
            g2d.drawLine( _startPosX + 30, _startPosY + 75, _startPosX + 30, _startPosY + 50);
        }

        g2d.setColor(entitySeaplane.getBodyColor());
        // Закрашиваем корпус
        g2d.fillOval(_startPosX, _startPosY + 34, 20, 20);
        g2d.fillOval(_startPosX, _startPosY + 44, 20, 20);
        g2d.fillOval(_startPosX, _startPosY + 45, 10, 10);
        g2d.fillRect(_startPosX + 10, _startPosY + 34, 160, 30);

        g2d.setColor(entitySeaplane.getAdditionalColor());
        // Закрашиваем дополнительные элементы
        g2d.fillPolygon(xPointsTop, yPointsTop, 3);
        g2d.fillPolygon(xPointsBottom, yPointsBottom, 3);
        g2d.fillPolygon(xPointsKeel, yPointsKeel, 3);

        _drawingSeaplanePortholes.drawSeaplanePortholes(g, Color.CYAN, _startPosX + 10, _startPosY + 41);

        g2d.setColor(Color.BLACK);
        // Рисуем триммера
        g2d.drawOval( _startPosX, _startPosY+30, 10, 10);
        g2d.drawOval( _startPosX+30, _startPosY+30, 10, 10);
        g2d.drawRect( _startPosX+5, _startPosY+30, 30, 10);

        // Рисуем крыло
        g2d.drawOval( _startPosX + 70, _startPosY + 45, 6, 6);
        g2d.drawOval( _startPosX + 130, _startPosY + 45, 6, 6);
        g2d.drawRect( _startPosX + 75, _startPosY + 45, 60, 6);

        // Закрашиваем триммера
        g2d.fillOval( _startPosX, _startPosY+30, 10, 10);
        g2d.fillOval( _startPosX+30, _startPosY+30, 10, 10);
        g2d.fillRect( _startPosX+5, _startPosY+30, 30, 10);

        // Закрашиваем крыло
        g2d.fillOval( _startPosX + 70, _startPosY + 45, 6, 6);
        g2d.fillOval( _startPosX + 130, _startPosY + 45, 6, 6);
        g2d.fillRect( _startPosX + 75, _startPosY + 45, 60, 6);

        // Поплавки
        if (entitySeaplane.getFloats()) {
            g2d.drawLine(_startPosX + 125, _startPosY + 65, _startPosX + 125, _startPosY + 80);
            g2d.drawLine(_startPosX + 50, _startPosY + 65, _startPosX + 50, _startPosY + 80);
            g2d.fillOval(_startPosX + 40, _startPosY + 75, 10, 10);
            g2d.fillOval(_startPosX + 125, _startPosY + 75, 10, 10);
            g2d.fillRect(_startPosX + 45, _startPosY + 75, 85, 10);
        }
        g2d.setColor(Color.RED);
        // Надувная лодка
        if (entitySeaplane.getInflatableBoat()) {
            g2d.fillOval(_startPosX, _startPosY + 60, 8, 8);
            g2d.fillOval(_startPosX + 165, _startPosY + 60, 8, 8);
            g2d.fillRect(_startPosX + 4, _startPosY + 60, 165, 8);
        }
    }
}
